@@ -61,7 +61,7 @@ class Exceptions:
 
 class IoTDataPlaneClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
     """
 
@@ -77,31 +77,31 @@ class IoTDataPlaneClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#can_paginate)
         """
 
     def delete_thing_shadow(
-        self, *, thingName: str, shadowName: str = None
+        self, *, thingName: str, shadowName: str = ...
     ) -> DeleteThingShadowResponseTypeDef:
         """
         Deletes the shadow for the specified thing.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#delete_thing_shadow)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#generate_presigned_url)
         """
 
@@ -109,37 +109,37 @@ class IoTDataPlaneClient(BaseClient):
         """
         Gets the details of a single retained message for the specified topic.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client.get_retained_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client.get_retained_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#get_retained_message)
         """
 
     def get_thing_shadow(
-        self, *, thingName: str, shadowName: str = None
+        self, *, thingName: str, shadowName: str = ...
     ) -> GetThingShadowResponseTypeDef:
         """
         Gets the shadow for the specified thing.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#get_thing_shadow)
         """
 
     def list_named_shadows_for_thing(
-        self, *, thingName: str, nextToken: str = None, pageSize: int = None
+        self, *, thingName: str, nextToken: str = ..., pageSize: int = ...
     ) -> ListNamedShadowsForThingResponseTypeDef:
         """
         Lists the shadows for the specified thing.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#list_named_shadows_for_thing)
         """
 
     def list_retained_messages(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListRetainedMessagesResponseTypeDef:
         """
         Lists summary information about the retained messages stored for the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client.list_retained_messages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client.list_retained_messages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#list_retained_messages)
         """
 
@@ -147,14 +147,14 @@ class IoTDataPlaneClient(BaseClient):
         self,
         *,
         topic: str,
-        qos: int = None,
-        retain: bool = None,
-        payload: Union[bytes, IO[bytes], StreamingBody] = None
+        qos: int = ...,
+        retain: bool = ...,
+        payload: Union[bytes, IO[bytes], StreamingBody] = ...
     ) -> None:
         """
         Publishes an MQTT message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client.publish)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client.publish)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#publish)
         """
 
@@ -163,12 +163,12 @@ class IoTDataPlaneClient(BaseClient):
         *,
         thingName: str,
         payload: Union[bytes, IO[bytes], StreamingBody],
-        shadowName: str = None
+        shadowName: str = ...
     ) -> UpdateThingShadowResponseTypeDef:
         """
         Updates the shadow for the specified thing.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#update_thing_shadow)
         """
 
@@ -176,6 +176,6 @@ class IoTDataPlaneClient(BaseClient):
         self, operation_name: Literal["list_retained_messages"]
     ) -> ListRetainedMessagesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/iot-data.html#IoTDataPlane.Paginator.ListRetainedMessages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/paginators.html#listretainedmessagespaginator)
         """
